==> open-xchange-drive_7.4.1.orig.tar.bz2: open-xchange-drive-7.4.1/com.openexchange.drive/src/com/openexchange/drive/internal/PathNormalizer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2013 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.drive.internal;

import java.text.Normalizer;
import java.text.Normalizer.Form;


/**
 * {@link PathNormalizer}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class PathNormalizer {

    /**
     * Normalizes a file- or directory path. The supplied string will be normalized according to the {@link Form#NFC} normalization from,
     * i.e. canonical decomposition, followed by canonical composition.
     *
     * @param path The file- or directory path to normalize
     * @return The normalized form
     */
    public static String normalize(String path) {
        return Normalizer.normalize(path, Form.NFC);
    }

    /**
     * Gets a value indicating whether the supplied file- or directory path is normalized according to the {@link Form#NFC} normalization
     * from, i.e. canonical decomposition, followed by canonical composition.
     *
     * @param path The file- or directory path to check
     * @return <code>true</code> if the path is normalized, <code>false</code>, otherwise
     */
    public static boolean isNormalized(String path) {
        return Normalizer.isNormalized(path, Form.NFC);
    }

    /**
     * Gets a value indicating whether the supplied file- or directory path are considered equal when being in their {@link Form#NFC}
     * normalization from, i.e. canonical decomposition, followed by canonical composition.
     *
     * @param path1 The first path to check
     * @param path2 The second path to check
     * @return <code>true</code> if both paths are equal, <code>false</code>, otherwise
     */
    public static boolean equals(String path1, String path2) {
        return null == path1 ? null == path2 : normalize(path1).equals(normalize(path2));
    }

}

==> open-xchange-drive_7.6.1.orig.tar.bz2: open-xchange-drive-7.6.1/com.openexchange.drive/src/com/openexchange/drive/internal/PathNormalizer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2013 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.drive.internal;

import java.text.Normalizer;
import java.text.Normalizer.Form;


/**
 * {@link PathNormalizer}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 */
public class PathNormalizer {

    /**
     * Normalizes a file- or directory path. The supplied string will be normalized according to the {@link Form#NFC} normalization from,
     * i.e. canonical decomposition, followed by canonical composition.
     *
     * @param path The file- or directory path to normalize
     * @return The normalized form
     */
    public static String normalize(String path) {
        return Normalizer.normalize(path, Form.NFC);
    }

    /**
     * Gets a value indicating whether the supplied file- or directory path is normalized according to the {@link Form#NFC} normalization
     * from, i.e. canonical decomposition, followed by canonical composition.
     *
     * @param path The file- or directory path to check
     * @return <code>true</code> if the path is normalized, <code>false</code>, otherwise
     */
    public static boolean isNormalized(String path) {
        return Normalizer.isNormalized(path, Form.NFC);
    }

    /**
     * Gets a value indicating whether the supplied file- or directory path are considered equal when being in their {@link Form#NFC}
     * normalization from, i.e. canonical decomposition, followed by canonical composition.
     *
     * @param path1 The first path to check
     * @param path2 The second path to check
     * @return <code>true</code> if both paths are equal, <code>false</code>, otherwise
     */
    public static boolean equals(String path1, String path2) {
        if (null == path1) {
            return null == path2;
        } else if (null == path2) {
            return false;
        } else {
            return normalize(path1).equals(normalize(path2));
        }
    }

}
